Welcome to acdh-tei-pyutils's documentation!
=============================================
.. toctree::
   :maxdepth: 2
   :caption: Contents:

   readme
   installation
   usage
   modules
   authors
   changelog
   code_of_conduct

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
